==> mingw-w64-aws-sdk-cpp-1.10.9-1.src.tar.zst: aws-sdk-cpp-1.10.9/aws-cpp-sdk-lex-models/include/aws/lex-models/model/GetBuiltinIntentResult.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/lex-models/LexModelBuildingService_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/lex-models/model/Locale.h>
#include <aws/lex-models/model/BuiltinIntentSlot.h>
#include <utility>

namespace Aws
{
template<typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils
{
namespace Json
{
  class JsonValue;
} // namespace Json
} // namespace Utils
namespace LexModelBuildingService
{
namespace Model
{
  class AWS_LEXMODELBUILDINGSERVICE_API GetBuiltinIntentResult
  {
  public:
    GetBuiltinIntentResult();
    GetBuiltinIntentResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
    GetBuiltinIntentResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);


    /**
     * <p>The unique identifier for a built-in intent.</p>
     */
    inline const Aws::String& GetSignature() const{ return m_signature; }

    /**
     * <p>The unique identifier for a built-in intent.</p>
     */
    inline void SetSignature(const Aws::String& value) { m_signature = value; }

    /**
     * <p>The unique identifier for a built-in intent.</p>
     */
    inline void SetSignature(Aws::String&& value) { m_signature = std::move(value); }

    /**
     * <p>The unique identifier for a built-in intent.</p>
     */
    inline void SetSignature(const char* value) { m_signature.assign(value); }

    /**
     * <p>The unique identifier for a built-in intent.</p>
     */
    inline GetBuiltinIntentResult& WithSignature(const Aws::String& value) { SetSignature(value); return *this;}

    /**
     * <p>The unique identifier for a built-in intent.</p>
     */
    inline GetBuiltinIntentResult& WithSignature(Aws::String&& value) { SetSignature(std::move(value)); return *this;}

    /**
     * <p>The unique identifier for a built-in intent.</p>
     */
    inline GetBuiltinIntentResult& WithSignature(const char* value) { SetSignature(value); return *this;}


    /**
     * <p>A list of locales that the intent supports.</p>
     */
    inline const Aws::Vector<Locale>& GetSupportedLocales() const{ return m_supportedLocales; }

    /**
     * <p>A list of locales that the intent supports.</p>
     */
    inline void SetSupportedLocales(const Aws::Vector<Locale>& value) { m_supportedLocales = value; }

    /**
     * <p>A list of locales that the intent supports.</p>
     */
    inline void SetSupportedLocales(Aws::Vector<Locale>&& value) { m_supportedLocales = std::move(value); }

    /**
     * <p>A list of locales that the intent supports.</p>
     */
    inline GetBuiltinIntentResult& WithSupportedLocales(const Aws::Vector<Locale>& value) { SetSupportedLocales(value); return *this;}

    /**
     * <p>A list of locales that the intent supports.</p>
     */
    inline GetBuiltinIntentResult& WithSupportedLocales(Aws::Vector<Locale>&& value) { SetSupportedLocales(std::move(value)); return *this;}

    /**
     * <p>A list of locales that the intent supports.</p>
     */
    inline GetBuiltinIntentResult& AddSupportedLocales(const Locale& value) { m_supportedLocales.push_back(value); return *this; }

    /**
     * <p>A list of locales that the intent supports.</p>
     */
    inline GetBuiltinIntentResult& AddSupportedLocales(Locale&& value) { m_supportedLocales.push_back(std::move(value)); return *this; }


    /**
     * <p>An array of <code>BuiltinIntentSlot</code> objects, one entry for each slot
     * type in the intent.</p>
     */
    inline const Aws::Vector<BuiltinIntentSlot>& GetSlots() const{ return m_slots; }

    /**
     * <p>An array of <code>BuiltinIntentSlot</code> objects, one entry for each slot
     * type in the intent.</p>
     */
    inline void SetSlots(const Aws::Vector<BuiltinIntentSlot>& value) { m_slots = value; }

    /**
     * <p>An array of <code>BuiltinIntentSlot</code> objects, one entry for each slot
     * type in the intent.</p>
     */
    inline void SetSlots(Aws::Vector<BuiltinIntentSlot>&& value) { m_slots = std::move(value); }

    /**
     * <p>An array of <code>BuiltinIntentSlot</code> objects, one entry for each slot
     * type in the intent.</p>
     */
    inline GetBuiltinIntentResult& WithSlots(const Aws::Vector<BuiltinIntentSlot>& value) { SetSlots(value); return *this;}

    /**
     * <p>An array of <code>BuiltinIntentSlot</code> objects, one entry for each slot
     * type in the intent.</p>
     */
    inline GetBuiltinIntentResult& WithSlots(Aws::Vector<BuiltinIntentSlot>&& value) { SetSlots(std::move(value)); return *this;}

    /**
     * <p>An array of <code>BuiltinIntentSlot</code> objects, one entry for each slot
     * type in the intent.</p>
     */
    inline GetBuiltinIntentResult& AddSlots(const BuiltinIntentSlot& value) { m_slots.push_back(value); return *this; }

    /**
     * <p>An array of <code>BuiltinIntentSlot</code> objects, one entry for each slot
     * type in the intent.</p>
     */
    inline GetBuiltinIntentResult& AddSlots(BuiltinIntentSlot&& value) { m_slots.push_back(std::move(value)); return *this; }

  private:

    Aws::String m_signature;

    Aws::Vector<Locale> m_supportedLocales;

    Aws::Vector<BuiltinIntentSlot> m_slots;
  };

} // namespace Model
} // namespace LexModelBuildingService
} // namespace Aws

==> mingw-w64-aws-sdk-cpp-1.10.55-1.src.tar.zst: aws-sdk-cpp-1.10.55/aws-cpp-sdk-lex-models/include/aws/lex-models/model/GetBuiltinIntentResult.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/lex-models/LexModelBuildingService_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/lex-models/model/Locale.h>
#include <aws/lex-models/model/BuiltinIntentSlot.h>
#include <utility>

namespace Aws
{
template<typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils
{
namespace Json
{
  class JsonValue;
} // namespace Json
} // namespace Utils
namespace LexModelBuildingService
{
namespace Model
{
  class GetBuiltinIntentResult
  {
  public:
    AWS_LEXMODELBUILDINGSERVICE_API GetBuiltinIntentResult();
    AWS_LEXMODELBUILDINGSERVICE_API GetBuiltinIntentResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
    AWS_LEXMODELBUILDINGSERVICE_API GetBuiltinIntentResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);


    /**
     * <p>The unique identifier for a built-in intent.</p>
     */
    inline const Aws::String& GetSignature() const{ return m_signature; }

    /**
     * <p>The unique identifier for a built-in intent.</p>
     */
    inline void SetSignature(const Aws::String& value) { m_signature = value; }

    /**
     * <p>The unique identifier for a built-in intent.</p>
     */
    inline void SetSignature(Aws::String&& value) { m_signature = std::move(value); }

    /**
     * <p>The unique identifier for a built-in intent.</p>
     */
    inline void SetSignature(const char* value) { m_signature.assign(value); }

    /**
     * <p>The unique identifier for a built-in intent.</p>
     */
    inline GetBuiltinIntentResult& WithSignature(const Aws::String& value) { SetSignature(value); return *this;}

    /**
     * <p>The unique identifier for a built-in intent.</p>
     */
    inline GetBuiltinIntentResult& WithSignature(Aws::String&& value) { SetSignature(std::move(value)); return *this;}

    /**
     * <p>The unique identifier for a built-in intent.</p>
     */
    inline GetBuiltinIntentResult& WithSignature(const char* value) { SetSignature(value); return *this;}


    /**
     * <p>A list of locales that the intent supports.</p>
     */
    inline const Aws::Vector<Locale>& GetSupportedLocales() const{ return m_supportedLocales; }

    /**
     * <p>A list of locales that the intent supports.</p>
     */
    inline void SetSupportedLocales(const Aws::Vector<Locale>& value) { m_supportedLocales = value; }

    /**
     * <p>A list of locales that the intent supports.</p>
     */
    inline void SetSupportedLocales(Aws::Vector<Locale>&& value) { m_supportedLocales = std::move(value); }

    /**
     * <p>A list of locales that the intent supports.</p>
     */
    inline GetBuiltinIntentResult& WithSupportedLocales(const Aws::Vector<Locale>& value) { SetSupportedLocales(value); return *this;}

    /**
     * <p>A list of locales that the intent supports.</p>
     */
    inline GetBuiltinIntentResult& WithSupportedLocales(Aws::Vector<Locale>&& value) { SetSupportedLocales(std::move(value)); return *this;}

    /**
     * <p>A list of locales that the intent supports.</p>
     */
    inline GetBuiltinIntentResult& AddSupportedLocales(const Locale& value) { m_supportedLocales.push_back(value); return *this; }

    /**
     * <p>A list of locales that the intent supports.</p>
     */
    inline GetBuiltinIntentResult& AddSupportedLocales(Locale&& value) { m_supportedLocales.push_back(std::move(value)); return *this; }


    /**
     * <p>An array of <code>BuiltinIntentSlot</code> objects, one entry for each slot
     * type in the intent.</p>
     */
    inline const Aws::Vector<BuiltinIntentSlot>& GetSlots() const{ return m_slots; }

    /**
     * <p>An array of <code>BuiltinIntentSlot</code> objects, one entry for each slot
     * type in the intent.</p>
     */
    inline void SetSlots(const Aws::Vector<BuiltinIntentSlot>& value) { m_slots = value; }

    /**
     * <p>An array of <code>BuiltinIntentSlot</code> objects, one entry for each slot
     * type in the intent.</p>
     */
    inline void SetSlots(Aws::Vector<BuiltinIntentSlot>&& value) { m_slots = std::move(value); }

    /**
     * <p>An array of <code>BuiltinIntentSlot</code> objects, one entry for each slot
     * type in the intent.</p>
     */
    inline GetBuiltinIntentResult& WithSlots(const Aws::Vector<BuiltinIntentSlot>& value) { SetSlots(value); return *this;}

    /**
     * <p>An array of <code>BuiltinIntentSlot</code> objects, one entry for each slot
     * type in the intent.</p>
     */
    inline GetBuiltinIntentResult& WithSlots(Aws::Vector<BuiltinIntentSlot>&& value) { SetSlots(std::move(value)); return *this;}

    /**
     * <p>An array of <code>BuiltinIntentSlot</code> objects, one entry for each slot
     * type in the intent.</p>
     */
    inline GetBuiltinIntentResult& AddSlots(const BuiltinIntentSlot& value) { m_slots.push_back(value); return *this; }

    /**
     * <p>An array of <code>BuiltinIntentSlot</code> objects, one entry for each slot
     * type in the intent.</p>
     */
    inline GetBuiltinIntentResult& AddSlots(BuiltinIntentSlot&& value) { m_slots.push_back(std::move(value)); return *this; }

  private:

    Aws::String m_signature;

    Aws::Vector<Locale> m_supportedLocales;

    Aws::Vector<BuiltinIntentSlot> m_slots;
  };

} // namespace Model
} // namespace LexModelBuildingService
} // namespace Aws
